//! # Network representation
//!
//! Solving network problems as linear programs.
pub mod representation;
